@@ -1,6 +1,6 @@
 // -*- mode: cpp; mode: fold -*-
 // Description								/*{{{*/
-// $Id: rsh.cc,v 1.7 2004/01/07 20:39:38 mdz Exp $
+// $Id: rsh.cc,v 1.6.2.1 2004/01/16 18:58:50 mdz Exp $
 /* ######################################################################
 
    RSH method - Transfer files via rsh compatible program
@@ -110,6 +110,8 @@ bool RSHConn::Connect(string Host, string User)
       // Probably should do
       // dup2(open("/dev/null",O_RDONLY),STDERR_FILENO);
 
+      Args[i++] = Prog;
+
       // Insert user-supplied command line options
       Configuration::Item const *Opts = RshOptions;
       if (Opts != 0)
@@ -123,7 +125,6 @@ bool RSHConn::Connect(string Host, string User)
          }
       }
 
-      Args[i++] = Prog;
       if (User.empty() == false) {
          Args[i++] = "-l";
 	 Args[i++] = User.c_str();
@@ -229,7 +230,7 @@ bool RSHConn::WriteMsg(string &Text,bool Sync,const char *Fmt,...)
       int Res = write(WriteFd,S + Start,Len);
       if (Res <= 0)
       {
-         _error->Errno("write",_("Write Error"));
+         _error->Errno("write",_("Write error"));
          Close();
          return false;
       }
@@ -261,7 +262,7 @@ bool RSHConn::Size(const char *Path,unsigned long &Size)
    char *End;
    Size = strtoul(Msg.c_str(),&End,10);
    if (End == Msg.c_str())
-      return _error->Error(_("File Not Found"));
+      return _error->Error(_("File not found"));
    return true;
 }
 									/*}}}*/
@@ -278,8 +279,7 @@ bool RSHConn::ModTime(const char *Path, time_t &Time)
       return false;
 
    // Parse it
-   StrToTime(Msg,Time);
-   return true;
+   return FTPMDTMStrToTime(Msg.c_str(), Time);
 }
 									/*}}}*/
 // RSHConn::Get - Get a file						/*{{{*/
@@ -430,7 +430,7 @@ bool RSHMethod::Fetch(FetchItem *Itm)
        Server->ModTime(File,FailTime) == false)
    {
       //Fail(true);
-      //_error->Error(_("File Not Found")); // Will be handled by Size
+      //_error->Error(_("File not found")); // Will be handled by Size
       return false;
    }
    Res.Size = Size;
